@@ -8,10 +8,14 @@ def getSolcatcherFlaskUrl():
   return 'https://solcatcher.io/flask'
 def getSolcatcherTsUrl():
   return 'https://solcatcher.io/typescript'
-def getEndpointUrl(endpoint=None,callType=None,url=None):
-  url = url or getSolcatcherUrl(callType=callType)
-  endpoint = make_endpoint(endpoint or '/')
-  return get_url(url,endpoint)
+
+def getEndpointUrl(endpoint=None,url=None):
+  
+  if endpoint:
+    url = eatAll(url,['/'])
+    endpoint = eatAll(endpoint,['/'])
+    url= f"{url}/{endpoint}"
+  return url
 def get_url(url=None):
     if isinstance(url,dict):
       url = url.get('url',url)
